aboutsummaryrefslogtreecommitdiff
path: root/lib/CodeGen/CodeGenModule.cpp
diff options
context:
space:
mode:
authorDaniel Dunbar <daniel@zuster.org>2008-08-16 00:56:44 +0000
committerDaniel Dunbar <daniel@zuster.org>2008-08-16 00:56:44 +0000
commit488e993a135ce700b982bf099c3d6b856301d642 (patch)
tree56ae14c8665f94f96e94f60fd083493d24e3250a /lib/CodeGen/CodeGenModule.cpp
parent1c72ef092f3d931639cf44b4f4f9d0eedc1baa8f (diff)
Change WarnUnsupported to ErrorUnsupported (in name and in practice).
- We are beyond the point where this shows up often and when it does generating miscompiled files is bad. git-svn-id: https://llvm.org/svn/llvm-project/cfe/trunk@54836 91177308-0d34-0410-b5e6-96231b3b80d8
Diffstat (limited to 'lib/CodeGen/CodeGenModule.cpp')
-rw-r--r--lib/CodeGen/CodeGenModule.cpp14
1 files changed, 7 insertions, 7 deletions
diff --git a/lib/CodeGen/CodeGenModule.cpp b/lib/CodeGen/CodeGenModule.cpp
index 99390c1135..1867207248 100644
--- a/lib/CodeGen/CodeGenModule.cpp
+++ b/lib/CodeGen/CodeGenModule.cpp
@@ -65,10 +65,10 @@ void CodeGenModule::Release() {
assert(!verifyModule(TheModule));
}
/// WarnUnsupported - Print out a warning that codegen doesn't support the
/// specified stmt yet.
-void CodeGenModule::WarnUnsupported(const Stmt *S, const char *Type) {
- unsigned DiagID = getDiags().getCustomDiagID(Diagnostic::Warning,
+void CodeGenModule::ErrorUnsupported(const Stmt *S, const char *Type) {
+ unsigned DiagID = getDiags().getCustomDiagID(Diagnostic::Error,
"cannot codegen this %0 yet");
SourceRange Range = S->getSourceRange();
std::string Msg = Type;
@@ -76,10 +76,10 @@ void CodeGenModule::WarnUnsupported(const Stmt *S, const char *Type) {
&Msg, 1, &Range, 1);
}
/// WarnUnsupported - Print out a warning that codegen doesn't support the
/// specified decl yet.
-void CodeGenModule::WarnUnsupported(const Decl *D, const char *Type) {
- unsigned DiagID = getDiags().getCustomDiagID(Diagnostic::Warning,
+void CodeGenModule::ErrorUnsupported(const Decl *D, const char *Type) {
+ unsigned DiagID = getDiags().getCustomDiagID(Diagnostic::Error,
"cannot codegen this %0 yet");
std::string Msg = Type;
getDiags().Report(Context.getFullLoc(D->getLocation()), DiagID,
@@ -888,7 +888,7 @@ void CodeGenModule::EmitTopLevelDecl(Decl *D) {
case Decl::LinkageSpec: {
LinkageSpecDecl *LSD = cast<LinkageSpecDecl>(D);
if (LSD->getLanguage() == LinkageSpecDecl::lang_cxx)
- WarnUnsupported(LSD, "linkage spec");
+ ErrorUnsupported(LSD, "linkage spec");
// FIXME: implement C++ linkage, C linkage works mostly by C
// language reuse already.
break;
@@ -65,10 +65,10 @@ void CodeGenModule::Release() {
assert(!verifyModule(TheModule));
}
-/// WarnUnsupported - Print out a warning that codegen doesn't support the
+/// ErrorUnsupported - Print out an error that codegen doesn't support the
/// specified stmt yet.
@@ -76,10 +76,10 @@ void CodeGenModule::WarnUnsupported(const Stmt *S, const char *Type) {
&Msg, 1, &Range, 1);
}
-/// WarnUnsupported - Print out a warning that codegen doesn't support the
+/// ErrorUnsupported - Print out an error that codegen doesn't support the
/// specified decl yet.